////////////////////////////////////////////////////////////////////////////////
//
// BaseCut
// --------------
//
// Authors: Aran Garcia-Bellido (aran@fnal.gov),
//          Gabriella Gaudio (ggaudio@u.washington.edu)
//          Brigitte Vachon (vachon@fnal.gov)
//          Gordon Watts (gwatts@fnal.gov)
//
// Date: Oct. 01 2003
//
//  This is the abstract class from which both the histogram managing classes 
//  and the cut application classes are derived
//
// Modification:
// 4/27/2004, RS: Adjust to be used for NLO analysis.
//
//
////////////////////////////////////////////////////////////////////////////////

#ifndef BaseCut_h
#define BaseCut_h

#include "single_top_analysis/Particles.hpp"

#include <string>
#include <vector>

#include <TDirectory.h>

class BaseCut : public TNamed
{

public:

  // constructor
  inline  BaseCut(Particles *obj=0): _particleObj(obj) {};

  // destructor
  inline virtual ~BaseCut(){};

  // If we try to reSet the name
  virtual void SetName(const char *name);
  // Return a pointer to a named base cut
  static BaseCut *GetBaseCut (const std::string &name);

  // Matches the list of cuts with available predifined cuts and applies them 
  // if it is implemented in a class derived from AnalysisCut while fills 
  // histograms if it is implemented in a class derived from HistoCut class. 
  virtual bool Apply()=0;

  // This member function will be used in the class derived from HistoCut 
  // to book the histograms of interest for the analysis. 
  virtual void BookHistogram()=0;

   //this method return the cut list file name
  virtual std::string GetCutName()=0;

  // Return Directory associated with histogram task
  inline virtual TDirectory * GetDirectory(){ return _thisdirectory;};

 // Return Directory associated with histogram task
  inline virtual void SetDirectory( TDirectory * dir){_thisdirectory= dir;};

  inline virtual void PrintCut(const std::string &indent = ""){};

  // This is called when a cut processor has completed running on a full chain.
  inline virtual void DoneWithProcessingLoop (void) {};
  /// access the particle object
  inline Particles * GetParticleObj() { return _particleObj; };
  /// assign the particle object
  inline void SetParticleObj(Particles *obj) { _particleObj=obj; };

protected:

  // directory to put histograms and graphs into:
  TDirectory *_thisdirectory;
  // the particles class storing inputs
  // we need this for the npart ID and the weight
  Particles *_particleObj;

  ClassDef (BaseCut,1);

};

#endif





