///////////////////////////////////////////////////////////////////////////////
//
// CutBasic
// -----------------
//
// Authors: Reinhard Schwienhorst
//       
// Date: April 28 2004
// 
// This class is derived from the BaseCut Class and simply
// cuts on if the event has reconstructed objects
// 
///////////////////////////////////////////////////////////////////////////////

#ifndef CutBasic_h
#define CutBasic_h

#include "single_top_analysis/BaseCut.hpp"
#include "single_top_analysis/Particles.hpp"

#include <string>
#include <vector>
#include <sstream>

using namespace std;


class CutBasic : public BaseCut
{

public:

  // constructor
  CutBasic(Particles *obj,double elept=-1.,double eleeta=99.,double met=-1.,double jetpt=-1.,double jeteta=99.,int minjets=0,int maxjets=99,double jet1pt=0.,double jet1eta=99.);
  
  // destructor
  ~CutBasic();

  // methods:
  void BookHistogram(void );
  bool Apply();
  
  inline std::string GetCutName (void) { return "CutBasic"; };


private:
  // 
  //
  //////////////////////////////////////////////////////////////////////////
  // cut parameters:
  double _minElePt;
  double _maxEleEta;
  double _minMET;
  double _minJetPt;
  double _maxJetEta;
  // for jet counting, only consider those that pass the cut
  int _minNjets;
  int _maxNjets;
  // also allow for leading jet cuts
  double _minJet1Pt;
  double _maxJet1Eta;

};


#endif







