//
// CutListProcessor
//
//  Have fun with a list of BaseCut guys that we play with! Woo!
//
#ifndef __CutListProcessor__
#define __CutListProcessor__

#include "single_top_analysis/BaseCut.hpp"
#include "TH1F.h"

#include <vector>

class CutListProcessor : public BaseCut {
 public:
  
  // What shall we call ourselves??
  CutListProcessor (const std::string &name, bool always_pass = false);
  inline virtual ~CutListProcessor (void) {};
  
  // Add a new cut to the list to processes
  void AddCut (BaseCut *cut);
  
  // Pass these on with the appropriate code.
  virtual void BookHistogram(void);
  virtual bool Apply (Particles *obj);
  virtual std::string GetCutName (void);
  virtual void PrintCut (const std::string &indent = "");
  
  static void SetDebug (bool doit) {_g_debug = doit;}
  
  // If you have a BaseCut you want added at the start of every single
  // Created CutListProcessor, use the static routine below to add
  // a fucntor that has at least one method T::operator() (CutListProcessor *p).
  // That will Get called right after the CutListProcessor is constructed and you
  // can do whatever you like there.
  template<class T>
  static inline void AddDefaultBaseCut (T &creator)
  {
    defaultCuts().push_back(auto_insert_t_maker (creator));
  }
  
  // If you want to know what package we think we are currently running...
  static inline BaseCut *GetGurrentPackage (void) {
    return _currentPackage;
  }
  static inline Particles *GetCurrentReadEvent (void) {
    return _currentRE;
  }
  
 private:
  const std::string _name;
  // vector of tasks to be performed:
  std::vector<BaseCut *> _cut_histos;
  
   TH1F *_whoran;
  
  bool _always_pass;
  
  void clean_up_run (std::vector<BaseCut *>::iterator start,
		     std::vector<BaseCut *>::iterator end);
  
  static bool _g_debug;
  
  /// Below are the template classes, etc., needed to support
  /// adding arbitrary guys to the CutListProcessor.
  class auto_insert {
  public:
    virtual inline ~auto_insert (void)
    {}
    virtual void AddCuts (CutListProcessor *p) = 0;
  };
  
  template <class T> class auto_insert_t : public auto_insert {
  public:
    inline auto_insert_t (T &Create_functor)
      : _creator (Create_functor)
    {}
    inline void AddCuts (CutListProcessor *p) {
      _creator (p);
    }
  private:
    T _creator;
  };
  
  template<class T> static auto_insert_t<T> *auto_insert_t_maker (T &creator)
  {
    return new auto_insert_t<T> (creator);
  }
  static std::vector<auto_insert*> &defaultCuts(void);
  
  /// Tools for tracking what is going on
  static BaseCut *_currentPackage;
  static Particles *_currentRE;
};


#endif
