/******************************************************************************
 * HistogrammingNJets.hpp                                                     *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingNJets()              -- Parameterized Constructor          *
 *    ~HistogrammingNJets()             -- Destructor                         *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingNJets"       *
 *                                                                            *
 * Private Data Members of AnalysisMain class                                 *
 *    myTH1F* _hNJets                   -- Hist of Num of jets                *
 *                                                                            *
 * History                                                                    *
 *      19 Oct 2006 - Created by R. Schwienhorst for ATLAS                    *
 *      10 Nov 2006 - Modified by P. Ryan - cleanup and reorganized           *
 *****************************************************************************/

#ifndef HistogrammingNJets_h
#define HistogrammingNJets_h

#include "single_top_analysis/HistoCut.hpp"
#include "single_top_analysis/Particles.hpp"

#include <string>
#include <vector>
#include <sstream>

using namespace std;


class HistogrammingNJets : public HistoCut 
{

public:

  // Parameterized Donstructor
  HistogrammingNJets(Particles *obj);
  
  // Destructor
  ~HistogrammingNJets();

  // Get the name describing the cut
  inline std::string GetCutName() { return "HistogrammingNJets"; };

  // Book Histograms
  void BookHistogram();

  // Fill Histograms
  Bool_t Apply();
  
private:
  // Histograms declarations 
  myTH1F* _hNJets;  // Histogram of events passing cuts

};


#endif







