////////////////////////////////////////////////////////////////
//
// Purpose: Store 1-d or 2-d histograms in a directory structure
//
// Author: Reinhard Schwienhorst
//
// Date: 10/19/06
//
// Modifications:
//
/////////////////////////////////////////////////////////////////////
#include <TH1.h>
#include <TGraph.h>
#include <string>
#include <TDirectory.h>
#include <TObject.h>

class Particles;

class myTH1F: public TObject
{
 public:
  //  constructor
  myTH1F(TDirectory *baseDir,Particles *obj,const std::string& name, const std::string& title,
	 int nXBins, Double_t xMin, Double_t xMax);
  // destructor
  ~myTH1F() {};
  // fill method, fill only some of the histograms depending on npart
  // If the weight is <=0, use the global event weight (default).
  int Fill(Double_t x, Double_t myWeight=-1.);
  // Fill method that fills a histogram without using any weight
  int FillWithoutWeight(Double_t x);
  //
  // write output to the file
  int Write(TDirectory *baseDir);
  //
  // copy the content of this histogram into another.
  int Copy(myTH1F other);
  //
  // Divide this histogram by the other.
  int Divide(myTH1F other);
  //
  // Set the label for the X axis.
  void SetXAxisTitle(const TString label);
  // Set the label for the Yaxis.
  void SetYAxisTitle(const TString label);
  //
  // Set the label for individual bins on the X axis.
  void SetXAxisBinLabel(Int_t iBin,TString label);
  //
  // Get the number of bins.
  int GetNbinsX() {return _hincl->GetNbinsX(); };

  //-------------------------------------------------------
  // declare the histograms and make them public:
  // for both s-channel and t-channel:
  TH1F* _hincl;


  //-------------------------------------------------------


 private:
  // a pointer to the class storing objects and other things I might need
  Particles *_obj;

};
