/******************************************************************************
 * HistogrammingNJets.cpp                                                     *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingNJets()              -- Parameterized Constructor          *
 *    ~HistogrammingNJets()             -- Destructor                         *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingNJets"       *
 *                                                                            *
 * Private Data Members of AnalysisMain class                                 *
 *    myTH1F* _hNJets                   -- Hist of Num of jets                *
 *                                                                            *
 * History                                                                    *
 *      19 Oct 2006 - Created by R. Schwienhorst for ATLAS                    *
 *      10 Nov 2006 - Modified by P. Ryan - cleanup and reorganized           *
 *****************************************************************************/

#include "single_top_analysis/HistogrammingNJets.hpp"
#include<iostream>

using namespace std;

/******************************************************************************
 * HistogrammingNJets::NistogrammingNJets(Particles *obj)                     *
 *                                                                            *
 * Parameterized Constructor                                                  *
 *                                                                            *
 * Input:  Particle class                                                     *
 * Output: None                                                               *
 ******************************************************************************/
HistogrammingNJets::HistogrammingNJets(Particles *obj)
{
  SetParticleObj(obj);
} //HistogrammingNJets()

/******************************************************************************
 * HistogrammingNJets::~HistogrammingNJets()                                  *
 *                                                                            *
 * Destructor                                                                 *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
HistogrammingNJets::~HistogrammingNJets()
{
  
} //HistogrammingNJets

/******************************************************************************
 * void HistogrammingNJets::BookHistogram()                                          *
 *                                                                            *
 * Book Histograms                                                            *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
void HistogrammingNJets::BookHistogram(){
  
  // Histogram of Number of Jets
  _hNJets = DeclareTH1F("njets","Number of Jets",10,0.,10.);
  _hNJets->SetXAxisTitle("N_{Jets}");
  _hNJets->SetYAxisTitle("Events");
  //cout<<"end of HistogrammingNJets::BookHistogram"<<endl;

} //BookHistogram

/******************************************************************************
 * Bool_t HistogrammingNJets::Apply()                                         *
 *                                                                            *
 * Fill histograms                                                            *
 *                                                                            *
 * Input:  None                                                               *
 * Output: kTrue if successful                                                *
 ******************************************************************************/
Bool_t HistogrammingNJets::Apply()
{
  //cout<<"Begin of HistogrammingNJets::Apply()"<<endl;
  
  // Get Event Tree
  Particles *particlesObj = GetParticleObj();
  EventTree * evTree = particlesObj -> GetEventTree();
  
  // Fill Histograms
  _hNJets -> Fill(evTree -> PJet_N);

  //cout<<"End of HistogrammingNJets::Apply()"<<endl;
  return kTRUE;  
  
} //Apply












